#!/usr/bin/env python3

import numpy as np

class Node3D:
    def __init__(self, x, y, z, parent=None):
        self.coord = (x, y, z)
        self.parent = parent

    @property
    def x(self):
        return self.coord[0]

    @property
    def y(self):
        return self.coord[1]

    @property
    def z(self):
        return self.coord[2]



def bellande_step_3d(node0, node1, limit=75):
    delta_x = node1.x - node0.x
    delta_y = node1.y - node0.y
    delta_z = node1.z - node0.z
    
    dist = np.sqrt(delta_x ** 2 + delta_y ** 2 + delta_z ** 2)
    
    if dist < limit:
        return node1
    
    ratio = limit / dist
    step_x = node0.x + delta_x * ratio
    step_y = node0.y + delta_y * ratio
    step_z = node0.z + delta_z * ratio
    
    return Node3D(step_x, step_y, step_z)



#!/usr/bin/env python3

import numpy as np

class Node2D:
    def __init__(self, x, y, parent=None):
        self.coord = (x, y)
        self.parent = parent

    @property
    def x(self):
        return self.coord[0]

    @property
    def y(self):
        return self.coord[1]


def bellande_step_2d(node0, node1, limit=75):
    delta_x = node1.x - node0.x
    delta_y = node1.y - node0.y
    dist = np.sqrt(delta_x ** 2 + delta_y ** 2)

    if dist < limit:
        return node1

    ratio = limit / dist
    step_x = node0.x + delta_x * ratio
    step_y = node0.y + delta_y * ratio

    return Node2D(step_x, step_y)



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="bellande_robot_step",
    version="0.2.2",
    description="Robots Step",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="RonaldsonBellande",
    author_email="ronaldsonbellande@gmail.com",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    include_package_data=True,
    install_requires=[
        "numpy",
    ],
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Programming Language :: Python",
    ],
    keywords=["package", "setuptools"],
    python_requires=">=3.0",
    extras_require={
        "dev": ["pytest", "pytest-cov[all]", "mypy", "black"],
    },
    entry_points={
        'console_scripts': [
            'bellande_step_2d = bellande_robot_step.bellande_robot_step_2d:bellande_step_2d',
            'bellande_step_3d = bellande_robot_step.bellande_robot_step_3d:bellande_step_3d',
            'bellande_step_4d = bellande_robot_step.bellande_robot_step_4d:bellande_step_4d',
            'bellande_step_5d = bellande_robot_step.bellande_robot_step_5d:bellande_step_5d',
            'bellande_step_6d = bellande_robot_step.bellande_robot_step_6d:bellande_step_6d',
            'bellande_step_7d = bellande_robot_step.bellande_robot_step_7d:bellande_step_7d',
            'bellande_step_8d = bellande_robot_step.bellande_robot_step_8d:bellande_step_8d',
            'bellande_step_9d = bellande_robot_step.bellande_robot_step_9d:bellande_step_9d',
            'bellande_step_10d = bellande_robot_step.bellande_robot_step_10d:bellande_step_10d',
        ],
    },
    project_urls={
        "Home": "https://github.com/RonaldsonBellande/bellande_robot_step",
        "Homepage": "https://github.com/RonaldsonBellande/bellande_robot_step",
        "documentation": "https://github.com/RonaldsonBellande/bellande_robot_step",
        "repository": "https://github.com/RonaldsonBellande/bellande_robot_step",
    },
)
